@@ -1,4 +1,5 @@
 """Related classes for the Cloud Storage."""
+import io
 import multiprocessing
 import os
 import threading
@@ -257,6 +258,17 @@ class CloudClient:
 
         return image_path if image_path else key
 
+    @staticmethod
+    def download_fileobj(
+            identifier: str,
+            bucket: str,
+            key: str,
+            fileobj
+    ) -> str:
+        client = CloudClient._get_client(identifier, False)
+        client.download_fileobj(bucket, key, fileobj)
+        return
+
     @staticmethod
     def download_files(
             identifier: str,
@@ -319,7 +331,6 @@ class CloudClient:
         client = CloudClient._get_client(job.identifier)
 
         for item in job.batch:
-            print(item.bucket, item.key, item.file_name)
             client.download_file(item.bucket, item.key, item.file_name)
 
     @staticmethod
